@@ -8,7 +8,11 @@ from History import Historian  # noqa autopep8
 hist = Historian()
 ls = [np.nan, True, True, np.nan, False, np.nan, np.nan, np.nan, True]
 fs = [True,   True, True, True,   False, False,  False,  False,  True]
+unfilled_fs = [True, None, None, None,
+               False, None, None, None, True]
 ns = [True,   True, True, True,   False, False,  False,  True,   True]
+unfilled_ns = [True, None, None, None,
+               False, None, None, True, True]
 arr = np.array(ls)
 test_ffill = np.array(fs)
 test_nfill = np.array(ns)
@@ -39,6 +43,10 @@ class TestHistorian:
         nfill = hist.fill(arr, 'nearest')
         assert np.array_equal(nfill, test_nfill)
 
+    def test_unfill(self):
+        hist.unfill(fs) == unfilled_fs
+        hist.unfill(ns) == unfilled_ns
+
     def test_get_optimal_signals(self):
         f_signals = hist.get_optimal_signals(close, n=2, method='ffill')
         assert np.array_equal(f_signals, test_ffill)
